==> adlint_1.6.0.orig.tar.gz: adlint-1.6.0/lib/adlint/ld/metric.rb <==
# Quality metric measurement classes for cross module analysis.
#
# Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
# Copyright:: Copyright (C) 2010-2012, OGIS-RI Co.,Ltd.
# License::   GPLv3+: GNU General Public License version 3 or later
#
# Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>

#--
#     ___    ____  __    ___   _________
#    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
#   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
#  / __  |/ /_/ / /___/ / /|  /  / /
# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2012, OGIS-RI Co.,Ltd.
#
# This file is part of AdLint.
#
# AdLint is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# AdLint is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# AdLint.  If not, see <http://www.gnu.org/licenses/>.
#
#++

require "adlint/metric"
require "adlint/report"

module AdLint #:nodoc:
module Ld #:nodoc:

  class FN_CALL < MetricMeasurement
    def initialize(context)
      super
      @context = context
      @context[:ld_function_traversal].on_definition += method(:measure)
    end

    private
    def do_prepare(context) end
    def do_execute(context) end

    def measure(function)
      call_graph = @context[:ld_function_call_graph]
      FN_CALL(FunctionIdentifier.new(function.name, function.signature.to_s),
              function.location, call_graph.all_callers_of(function).size)
    end
  end

end
end

==> adlint_1.10.0.orig.tar.gz: adlint-1.10.0/lib/adlint/ld/metric.rb <==
# Quality metric measurement classes for cross module analysis.
#
# Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
# Copyright:: Copyright (C) 2010-2012, OGIS-RI Co.,Ltd.
# License::   GPLv3+: GNU General Public License version 3 or later
#
# Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>

#--
#     ___    ____  __    ___   _________
#    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
#   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
#  / __  |/ /_/ / /___/ / /|  /  / /
# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2012, OGIS-RI Co.,Ltd.
#
# This file is part of AdLint.
#
# AdLint is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# AdLint is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# AdLint.  If not, see <http://www.gnu.org/licenses/>.
#
#++

require "adlint/metric"
require "adlint/report"

module AdLint #:nodoc:
module Ld #:nodoc:

  class FN_CALL < MetricMeasurement
    def initialize(context)
      super
      @context = context
      @context[:ld_function_traversal].on_definition += method(:measure)
    end

    private
    def do_prepare(context) end
    def do_execute(context) end

    def measure(function)
      call_graph = @context[:ld_function_call_graph]
      FN_CALL(FunctionIdentifier.new(function.name, function.signature),
              function.location, call_graph.all_callers_of(function).size)
    end
  end

end
end
